@@ -60,18 +60,21 @@ def managers(target, arg):
         ): print(f'{name:>{width}} {first}')
 
 def mappings(target, arg):
-    print('packages :')
+    width = 0
     packages = target.pkgmap
-    width = len(max(packages.keys(), key=len))+4
-    for name, pkg in sorted(packages.items()):
-        print(f'{name:>{width}} {pkg}')
+    if packages:
+        print('packages :')
+        width = len(max(packages.keys(), key=len))+4
+        for name, pkg in sorted(packages.items()):
+            print(f'{name:>{width}} {pkg}')
 
-    print('\nservices :')
     services = target.svcmap
-    w = len(max(services.keys(), key=len))+4
-    width = max(width, w)
-    for name, svc in sorted(services.items()):
-        print(f'{name:>{width}} {svc}')
+    if services:
+        print('\nservices :')
+        w = len(max(services.keys(), key=len))+4
+        width = max(width, w)
+        for name, svc in sorted(services.items()):
+            print(f'{name:>{width}} {svc}')
 
 def deploy(target, arg):
     target.deploy(arg)
